@@ -7,6 +7,7 @@ from snaptrade_client.apis.paths.snap_trade_login import SnapTradeLogin
 from snaptrade_client.apis.paths.snap_trade_list_users import SnapTradeListUsers
 from snaptrade_client.apis.paths.snap_trade_delete_user import SnapTradeDeleteUser
 from snaptrade_client.apis.paths.snap_trade_encrypted_jwt import SnapTradeEncryptedJWT
+from snaptrade_client.apis.paths.snap_trade_reset_user_secret import SnapTradeResetUserSecret
 from snaptrade_client.apis.paths.authorizations import Authorizations
 from snaptrade_client.apis.paths.authorizations_authorization_id import AuthorizationsAuthorizationId
 from snaptrade_client.apis.paths.session_events import SessionEvents
@@ -39,7 +40,7 @@ from snaptrade_client.apis.paths.currencies_rates_currency_pair import Currencie
 from snaptrade_client.apis.paths.exchanges import Exchanges
 from snaptrade_client.apis.paths.security_types import SecurityTypes
 from snaptrade_client.apis.paths.symbols import Symbols
-from snaptrade_client.apis.paths.symbols_ticker import SymbolsTicker
+from snaptrade_client.apis.paths.symbols_query import SymbolsQuery
 from snaptrade_client.apis.paths.activities import Activities
 from snaptrade_client.apis.paths.performance_custom import PerformanceCustom
 
@@ -52,6 +53,7 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.SNAP_TRADE_LIST_USERS: SnapTradeListUsers,
         PathValues.SNAP_TRADE_DELETE_USER: SnapTradeDeleteUser,
         PathValues.SNAP_TRADE_ENCRYPTED_JWT: SnapTradeEncryptedJWT,
+        PathValues.SNAP_TRADE_RESET_USER_SECRET: SnapTradeResetUserSecret,
         PathValues.AUTHORIZATIONS: Authorizations,
         PathValues.AUTHORIZATIONS_AUTHORIZATION_ID: AuthorizationsAuthorizationId,
         PathValues.SESSION_EVENTS: SessionEvents,
@@ -84,7 +86,7 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.EXCHANGES: Exchanges,
         PathValues.SECURITY_TYPES: SecurityTypes,
         PathValues.SYMBOLS: Symbols,
-        PathValues.SYMBOLS_TICKER: SymbolsTicker,
+        PathValues.SYMBOLS_QUERY: SymbolsQuery,
         PathValues.ACTIVITIES: Activities,
         PathValues.PERFORMANCE_CUSTOM: PerformanceCustom,
     }
@@ -98,6 +100,7 @@ path_to_api = PathToApi(
         PathValues.SNAP_TRADE_LIST_USERS: SnapTradeListUsers,
         PathValues.SNAP_TRADE_DELETE_USER: SnapTradeDeleteUser,
         PathValues.SNAP_TRADE_ENCRYPTED_JWT: SnapTradeEncryptedJWT,
+        PathValues.SNAP_TRADE_RESET_USER_SECRET: SnapTradeResetUserSecret,
         PathValues.AUTHORIZATIONS: Authorizations,
         PathValues.AUTHORIZATIONS_AUTHORIZATION_ID: AuthorizationsAuthorizationId,
         PathValues.SESSION_EVENTS: SessionEvents,
@@ -130,7 +133,7 @@ path_to_api = PathToApi(
         PathValues.EXCHANGES: Exchanges,
         PathValues.SECURITY_TYPES: SecurityTypes,
         PathValues.SYMBOLS: Symbols,
-        PathValues.SYMBOLS_TICKER: SymbolsTicker,
+        PathValues.SYMBOLS_QUERY: SymbolsQuery,
         PathValues.ACTIVITIES: Activities,
         PathValues.PERFORMANCE_CUSTOM: PerformanceCustom,
     }
