@@ -202,8 +202,9 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor204Async,
         ApiResponseForDefaultAsync,
@@ -211,7 +212,7 @@ class BaseApi(api_client.Api):
         AsyncGeneratorResponse,
     ]:
         """
-        Remove a brokerage authorization.
+        Delete brokerage authorization
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -264,6 +265,7 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -330,7 +332,7 @@ class BaseApi(api_client.Api):
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         stream: bool = False,
     ) -> typing.Union[
         ApiResponseFor204,
@@ -338,7 +340,7 @@ class BaseApi(api_client.Api):
         api_client.ApiResponseWithoutDeserialization,
     ]:
         """
-        Remove a brokerage authorization.
+        Delete brokerage authorization
         :param skip_deserialization: If true then api_response.response will be set but
             api_response.body and api_response.headers will not be deserialized into schema
             class instances
@@ -432,6 +434,7 @@ class RemoveBrokerageAuthorization(BaseApi):
         user_secret: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor204Async,
         ApiResponseForDefaultAsync,
@@ -448,6 +451,7 @@ class RemoveBrokerageAuthorization(BaseApi):
         return await self._aremove_brokerage_authorization_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def remove_brokerage_authorization(
@@ -484,6 +488,7 @@ class ApiFordelete(BaseApi):
         user_secret: typing.Optional[str] = None,
         query_params: typing.Optional[dict] = {},
         path_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor204Async,
         ApiResponseForDefaultAsync,
@@ -500,6 +505,7 @@ class ApiFordelete(BaseApi):
         return await self._aremove_brokerage_authorization_oapg(
             query_params=args.query,
             path_params=args.path,
+            **kwargs,
         )
     
     def delete(
